Change log
==========

1.0.0
-----

* Refactor the code to one folder

1.0.1
-----

* Add margin bottom to excel table div

1.0.2
-----

* Add row_header and col_header option to control whether to show the headers

1.0.3
-----

* Fix bug when openpyxl upgrade to 2.5.2

1.0.4
-----

* Add python 3 support

1.0.6
-----

* Fix bug when calls to the same file multiple times chunks the table together
* Fix bug date NameError when running in Python 3
* Use the new merged_cells interface of openpyxl
